@@ -27,7 +27,7 @@ has pubsub => sub {
 };
 has 'search_path';
 
-our $VERSION = '2.13';
+our $VERSION = '2.14';
 
 sub db {
   my $self = shift;
@@ -294,7 +294,7 @@ efficiently, by sharing a single database connection with many consumers.
 =head2 search_path
 
   my $path = $pg->search_path;
-  $pg      = $pg->search_path(['foo', 'public']);
+  $pg      = $pg->search_path(['$user', 'foo', 'public']);
 
 Schema search path assigned to all new connections.
 
